@@ -1,8 +1,12 @@
 #!/usr/bin/env python3
+"""
+QECore __init__ file.
+"""
+
 from __future__ import absolute_import, division, print_function, unicode_literals
 
 __author__ = """Michal Odehnal <modehnal@redhat.com>"""
-__version__ = "3.15"
+__version__ = "3.16"
 __copyright__ = "Copyright © 2018-2023 Red Hat, Inc."
 __license__ = "GPL"
 __all__ = (
@@ -17,6 +21,3 @@ __all__ = (
     "utility",
     "icons",
 )
-
-# For compatibility reasons as utils source code was in this file.
-from qecore.utility import *
