@@ -1,16 +1,35 @@
 #!/usr/bin/env python3
-from time import sleep
+"""
+Application class to be used from TestSandbox to keep list of running applications.
+"""
+
 import shlex
 import configparser
+from time import sleep
+from typing import TypeVar
 from subprocess import Popen, PIPE
-from dogtail.rawinput import typeText, pressKey, keyCombo
-from qecore.utility import run, overview_action
-from qecore.logger import QELogger
+from dogtail.rawinput import (  # pylint: disable=import-error
+    typeText,
+    pressKey,
+    keyCombo,
+)
+from qecore.utility import run, run_verbose, overview_action
+from qecore.logger import Logging
 
-log = QELogger()
+logging_class = Logging()
+log = logging_class.logger
+
+# We do this just to satisfy the typing hint but without the need to import entire class.
+gi_repository_Atspi_Accessible = TypeVar(  # pylint: disable=invalid-name
+    "gi_repository_Atspi_Accessible"
+)
 
 
 class Application:
+    """
+    Application class taking care of setup on application side.
+    """
+
     def __init__(
         self,
         component,
@@ -19,11 +38,10 @@ class Application:
         desktop_file_name="",
         desktop_file_path="",
         app_process_name="",
-        shell=None,
         session_type="",
         session_desktop="",
         kiosk=None,
-    ):
+    ) -> None:
         """
         .. note::
 
@@ -49,20 +67,21 @@ class Application:
         :param app_process_name: Name of application process if not same as component.
         """
 
-        log.info(
+        log.debug(
             " ".join(
                 (
                     f"__init__(self, component={component}, a11y_app_name={a11y_app_name},",
                     f"desktop_file_exists={desktop_file_exists},",
                     f"desktop_file_name={desktop_file_name},",
                     f"desktop_file_path={desktop_file_path},",
-                    f"app_process_name={app_process_name}, shell='shell',",
+                    f"app_process_name={app_process_name},",
                     f"session_type={session_type}, session_desktop={session_desktop})",
                 )
             )
         )
 
-        self.shell = shell
+        # Define shell as None in the moment on initialization.
+        self.shell = None
         self.kiosk = kiosk
         self.session_type = session_type
         self.session_desktop = session_desktop
@@ -79,17 +98,23 @@ class Application:
         self.application_list = []
         self.app_process_name = app_process_name if app_process_name else component
         self.icon = None
+        self.process = None
         self.get_desktop_file_data()
 
+        # To be removed in the future, no more camelCasing.
         if "Flatpak" not in f"{type(self)}":
             # Preserving old api names of functions.
-            self.getDesktopFileData = self.get_desktop_file_data
-            self.getRoot = self.get_root
-            self.isRunning = self.is_running
-            self.getPidList = self.get_pid_list
-            self.getAllKillCandidates = self.get_all_kill_candidates
+            self.getDesktopFileData = (  # pylint: disable=invalid-name
+                self.get_desktop_file_data
+            )
+            self.getRoot = self.get_root  # pylint: disable=invalid-name
+            self.isRunning = self.is_running  # pylint: disable=invalid-name
+            self.getPidList = self.get_pid_list  # pylint: disable=invalid-name
+            self.getAllKillCandidates = (  # pylint: disable=invalid-name
+                self.get_all_kill_candidates
+            )
 
-    def get_desktop_file_data(self):
+    def get_desktop_file_data(self) -> None:
         """
         Parse desktop file.
 
@@ -98,17 +123,29 @@ class Application:
             Do **NOT** call this by yourself. This method is called by :func:`__init__`.
         """
 
-        log.info(f"{self.component} get_desktop_file_data(self)")
+        log.debug(f"{self.component} get_desktop_file_data(self)")
+
+        desktop_file_help = """
+        Specify one when initializing your application in environment.py, options are:
+        1) Specify your <name>.desktop file name 'desktop_file_name=\"<name>\"'.
+        2) Provide full path to your .desktop file 'desktop_file_path=\"/path/to/desktop/file\"'.
+        ' ... = context.sandbox.get_application(..., desktop_file_name="", desktop_file_path="")
+        """
 
         # zenity/gnome-shell do not have desktop file.
         if self.desktop_file_exists:
             if self.desktop_file_path:
-                log.info(
-                    f"get_desktop_file_data: loading user provided .desktop file: '{self.desktop_file_path}'"
+                log.debug(
+                    " ".join(
+                        (
+                            "get_desktop_file_data: loading user provided .desktop file:",
+                            f"'{self.desktop_file_path}'",
+                        )
+                    )
                 )
                 desktop_file = self.desktop_file_path
             else:
-                desktop_run = run(
+                desktop_run = run_verbose(
                     " ".join(
                         (
                             f"rpm -qlf $(which {self.component}) |",
@@ -116,17 +153,16 @@ class Application:
                             "grep .desktop |",
                             f"grep '{self.desktop_file_name}'",
                         )
-                    ),
-                    verbose=True,
+                    )
                 )
 
                 if desktop_run[1] != 0:
-                    raise Exception(
+                    raise UserWarning(
                         f"Desktop file of application '{self.component}' was not found."
                     )
 
                 desktop_file = desktop_run[0].strip("\n")
-                log.info(
+                log.debug(
                     f"get_desktop_file_data: .desktop file found: '{desktop_file}'"
                 )
 
@@ -135,17 +171,14 @@ class Application:
                 assert False, "\n".join(
                     (
                         f"More than one .desktop file found: \n{desktop_file}\n",
-                        "Specify one when initializing your application in environment.py, options are:",
-                        "1) Specify your <name>.desktop file name 'desktop_file_name=\"<name>\"'.",
-                        "2) Provide full path to your .desktop file 'desktop_file_path=\"/path/to/desktop/file\"'.",
-                        ' ... = context.sandbox.get_application(..., desktop_file_name="", desktop_file_path="")\n',
+                        desktop_file_help,
                     )
                 )
 
             desktop_file_config = configparser.RawConfigParser()
             list_of_successfully_parsed_files = desktop_file_config.read(desktop_file)
 
-            if list_of_successfully_parsed_files == []:
+            if not list_of_successfully_parsed_files:
                 assert False, "".join(
                     (f"Failed attepmt to parse the .desktop file: '{desktop_file}'.")
                 )
@@ -153,11 +186,18 @@ class Application:
             self.name = desktop_file_config.get("Desktop Entry", "name")
             self.exec = desktop_file_config.get("Desktop Entry", "exec").split(" ")[0]
             self.icon = desktop_file_config.get("Desktop Entry", "icon", fallback=None)
-            log.info(
-                f"get_desktop_file_data: data name='{self.name}' exec='{self.exec}' icon='{self.icon}'"
+            log.debug(
+                " ".join(
+                    (
+                        "get_desktop_file_data:",
+                        f"data name='{self.name}'",
+                        f"exec='{self.exec}'",
+                        f"icon='{self.icon}'",
+                    )
+                )
             )
 
-    def start_via_command(self, command=None, **kwargs):
+    def start_via_command(self, command=None, **kwargs) -> None:
         """
         Start application via command.
 
@@ -178,7 +218,7 @@ class Application:
             if "kill" in str(key).lower():
                 kill_override = val
 
-        log.info(
+        log.debug(
             "".join(
                 (
                     f"{self.component} ",
@@ -201,6 +241,9 @@ class Application:
             sleep(0.5)
             keyCombo("<Alt><F2>")
             sleep(0.5)
+
+            # The self.shell is None in the moment of __init__.
+            # Setting the self.shell for all applications once TestSandbox has it.
             enter_a_command = self.shell.findChild(
                 lambda x: "activate" in x.actions and x.showing
             )
@@ -231,7 +274,7 @@ class Application:
         self.wait_before_app_starts(30)
         self.instance = self.get_root()
 
-    def start_via_menu(self, kill=None):
+    def start_via_menu(self, kill=None) -> None:
         """
         Start application via menu.
 
@@ -240,7 +283,7 @@ class Application:
         in a new gnome-classic as it lost the search bar.
         """
 
-        log.info(f"{self.component} start_via_menu(self)")
+        log.debug(f"{self.component} start_via_menu(self)")
 
         if self.kiosk:
             raise RuntimeError("Start via menu is not available in kiosk mode.")
@@ -251,7 +294,7 @@ class Application:
             )
 
         if not self.desktop_file_exists:
-            raise Exception(
+            raise UserWarning(
                 "".join(
                     (
                         f"Testing target '{self.a11y_app_name}' does not have desktop file. ",
@@ -274,7 +317,7 @@ class Application:
         self.wait_before_app_starts(30)
         self.instance = self.get_root()
 
-    def close_via_shortcut(self):
+    def close_via_shortcut(self) -> None:
         """
         Close application via shortcut.
 
@@ -288,10 +331,10 @@ class Application:
             Here are  a few examples: <Ctrl><Q> <Alt><F4> <Ctrl><Shift><Q>
         """
 
-        log.info(f"{self.component} close_via_shortcut(self)")
+        log.debug(f"{self.component} close_via_shortcut(self)")
 
         if not self.is_running():
-            raise Exception(
+            raise RuntimeWarning(
                 "".join(
                     (
                         f"Application '{self.a11y_app_name}' is no longer running. ",
@@ -305,18 +348,18 @@ class Application:
         self.wait_before_app_closes(30)
         self.instance = None
 
-    def already_running(self):
+    def already_running(self) -> None:
         """
         If application is started by other means, other than methods from this class,
         this will retrieve the root of the application.
         """
 
-        log.info(f"{self.component} already_running(self)")
+        log.debug(f"{self.component} already_running(self)")
 
         self.wait_before_app_starts(15)
         self.instance = self.get_root()
 
-    def get_root(self):
+    def get_root(self) -> gi_repository_Atspi_Accessible:
         """
         Get accessibility root of appllication.
 
@@ -327,15 +370,17 @@ class Application:
         You do not need to use this by yourself, but can be useful in some situations.
         """
 
-        log.info(f"{self.component} get_root(self) search by '{self.a11y_app_name}'")
+        log.debug(f"{self.component} get_root(self) search by '{self.a11y_app_name}'")
 
         # Importing here for issue with accessibility if the connection is not ready yet.
         # This will make sure the import will happen after the session is loaded.
-        from dogtail.tree import root
+        from dogtail.tree import (  # pylint: disable=import-error,import-outside-toplevel
+            root,
+        )
 
         return root.application(self.a11y_app_name)
 
-    def is_running(self):
+    def is_running(self) -> bool:
         """
         Get running state of application.
         This state is retrieved by checking if application is present in the accessibility tree.
@@ -347,13 +392,15 @@ class Application:
         You do not need to use this by yourself, but can be useful in some situations.
         """
 
-        log.info(f"{self.component} is_running(self)")
+        log.debug(f"{self.component} is_running(self)")
 
         is_running = False
 
         try:
             # Preventing issues of loading a11y on import before session is ready.
-            from dogtail.tree import root
+            from dogtail.tree import (  # pylint: disable=import-error,import-outside-toplevel
+                root,
+            )
 
             self.application_list = [x.name for x in root.applications()]
             for _ in range(3):
@@ -361,10 +408,10 @@ class Application:
                 if is_running:
                     break
             return is_running
-        except Exception:
+        except RuntimeError:
             return False
 
-    def get_pid_list(self):
+    def get_pid_list(self) -> str:
         """
         Get list of processes of running application.
 
@@ -374,18 +421,18 @@ class Application:
 
         .. note::
 
-            Do **NOT** call this by yourself. This method is called by :func:`get_all_kill_candidates`
-            when stopping the application.
+            Do **NOT** call this by yourself.
+            This method is called by :func:`get_all_kill_candidates` when stopping the application.
         """
 
-        log.info(f"{self.component} get_pid_list(self)")
+        log.debug(f"{self.component} get_pid_list(self)")
 
         if self.is_running():
             return run(f"pgrep -fla {self.app_process_name}").strip("\n")
 
-        return None
+        return ""
 
-    def get_all_kill_candidates(self):
+    def get_all_kill_candidates(self) -> list:
         """
         Take result of :func:`get_pid_list` and return only processes of application.
 
@@ -394,8 +441,8 @@ class Application:
 
         .. note::
 
-            Do **NOT** call this by yourself. This method is called by :func:`kill_application`\
-            when stopping the application.
+            Do **NOT** call this by yourself.
+            This method is called by :func:`kill_application` when stopping the application.
 
         If kill candidate happens to have ['runtest', 'behave', 'dogtail', '/usr/bin/gnome-shell']
         in its process name. Process will not be killed.
@@ -403,7 +450,7 @@ class Application:
         This prevents testname colliding with found process so we will not kill the test itself.
         """
 
-        log.info(f"{self.component} get_all_kill_candidates(self)")
+        log.debug(f"{self.component} get_all_kill_candidates(self)")
 
         application_pid_string = self.get_pid_list()
         if application_pid_string:
@@ -428,7 +475,7 @@ class Application:
 
         return final_pid_list
 
-    def kill_application(self):
+    def kill_application(self) -> None:
         """
         Kill application.
 
@@ -438,7 +485,7 @@ class Application:
         You do not need to use this by yourself, but can be useful in some situations.
         """
 
-        log.info(f"{self.component} kill(self)")
+        log.debug(f"{self.component} kill(self)")
 
         if self.is_running() and self.kill:
             if not self.kill_command:
@@ -448,7 +495,7 @@ class Application:
                 run(self.kill_command)
 
     # Following two could be merged, I could not think of a nice way of doing it though.
-    def wait_before_app_starts(self, time_limit):
+    def wait_before_app_starts(self, time_limit) -> None:
         """
         Wait before application starts.
 
@@ -456,7 +503,7 @@ class Application:
         :param time_limit: Number which signifies time before the run is stopped.
         """
 
-        log.info(
+        log.debug(
             "".join(
                 (
                     f"{self.component} ",
@@ -471,13 +518,14 @@ class Application:
             else:
                 return
 
-        assert False, "".join(
+        assert False, " ".join(
             (
-                f"Application '{self.a11y_app_name}' was not found in application tree: '{self.application_list}'."
+                f"Application '{self.a11y_app_name}' was not found",
+                f"in application tree: '{self.application_list}'.",
             )
         )
 
-    def wait_before_app_closes(self, time_limit):
+    def wait_before_app_closes(self, time_limit) -> None:
         """
         Wait before application stops.
 
@@ -485,7 +533,7 @@ class Application:
         :param time_limit: Number which signifies time before the run is stopped.
         """
 
-        log.info(
+        log.debug(
             "".join(
                 (
                     f"{self.component} ",
@@ -500,8 +548,9 @@ class Application:
             else:
                 return
 
-        assert False, "".join(
+        assert False, " ".join(
             (
-                f"Application '{self.a11y_app_name}' was still found in application tree: '{self.application_list}'."
+                f"Application '{self.a11y_app_name}' was still found",
+                f"in application tree: '{self.application_list}'.",
             )
         )
