@@ -1,14 +1,18 @@
 #!/usr/bin/env python3
+"""
+Get Node class to be used for common_steps.
+"""
+
 import sys
 import traceback
 import re
 
-# for python 3.6
-if not hasattr(re, "Pattern"):
-    re.Pattern = re._pattern_type
-
 from qecore.utility import QE_DEVELOPMENT, Tuple
 
+# For python 3.6.
+if not hasattr(re, "Pattern"):
+    re.Pattern = re._pattern_type  # pylint: disable=protected-access
+
 __author__ = """
 Filip Pokryvka <fpokryvk@redhat.com>,
 Michal Odehnal <modehnal@redhat.com>
@@ -22,7 +26,11 @@ if QE_DEVELOPMENT:
 
 
 class GetNode:
-    def __init__(self, context, **kwargs):
+    """
+    Get Node class for common_steps usage.
+    """
+
+    def __init__(self, context, **kwargs) -> None:
         """
         Initiate GetNode instance.
         Workhorse for most of the :py:mod:`common_steps`.
@@ -84,7 +92,7 @@ class GetNode:
         """
 
         # Importing here to prevent earlier import error when session is not ready yet.
-        from dogtail.tree import root
+        from dogtail.tree import root  # pylint: disable=import-error
 
         name = kwargs.get("name", None)
         role_name = kwargs.get("role_name", None)
@@ -92,7 +100,7 @@ class GetNode:
         attr = kwargs.get("attr", None)
         description = kwargs.get("description", None)
 
-        def string_to_int_tuple(arg):
+        def string_to_int_tuple(arg) -> Tuple:
             return Tuple((int(x) for x in arg.split(",")))
 
         self.size_low = string_to_int_tuple(kwargs.get("size_low", "1,0"))
@@ -116,9 +124,14 @@ class GetNode:
                 try:
                     self.root = root.application(a11y_root_name)
                 except Exception as error:
-                    raise Exception(
-                        f"You are attempting to use '{a11y_root_name}' as root application.\n{error}"
-                    )
+                    raise UserWarning(
+                        "".join(
+                            (
+                                f"You are attempting to use '{a11y_root_name}' ",
+                                f"as root application.\n{error}",
+                            )
+                        )
+                    ) from error
 
         # Root accessibility object's name is not given.
         else:
@@ -176,10 +189,11 @@ class GetNode:
         self.attr = (
             attr if attr in defined_attributes else None if attr is None else False
         )
-        assert self.attr is not False, "\n".join(
+        assert self.attr is not False, "".join(
             (
                 "\nUnknown attribute. Check your feature file!",
-                f"Attributes defined are '{str(defined_attributes)}'. You tried to use: '{self.attr}'",
+                f"\nAttributes defined are '{str(defined_attributes)}'. ",
+                f"You tried to use: '{self.attr}'",
             )
         )
 
@@ -196,8 +210,9 @@ class GetNode:
         )
         assert self.expect_positive is not None, "".join(
             (
-                f"\nUnknown expect_positive state. Check your feature file!"
-                f"Expected attribute is 'True' or 'False'. You tried to use: '{self.expect_positive}'"
+                "\nUnknown expect_positive state. Check your feature file!"
+                "\nExpected attribute is 'True' or 'False'. ",
+                f"You tried to use: '{self.expect_positive}'",
             )
         )
 
@@ -234,193 +249,184 @@ class GetNode:
                 and Tuple(x.size) <= self.size_high,
                 retry=self.retry,
             )
-        except Exception as error:
+        except Exception as error:  # pylint: disable=broad-except
             if self.expect_positive:
-                assert False, get_error_message(self, error)
+                assert False, self.get_error_message(self, error)
             else:
                 found_node = None
         return (self, found_node)
 
-    def __exit__(self, exc_type, exc_value, trcb):
+    def __exit__(self, exc_type, exc_value, trcb) -> bool:
         if exc_type is not None:
             return False
         return True
 
+    def format_string(self, string, bold=False) -> str:
+        """
+        Colour string based on environemnt.
 
-def get_center(node):
-    """
-    Simple utility to get the center of the node.
+        :param string: String to format.
+        :type string: str
 
-    :type node: <dogtail.tree.Node>
-    :param node: Node passed to the function.
+        :param bold: Bold text.
+        :type bold: bool
 
-    :rtype: tuple
-    :return: Tuple with coordinates of the center of a Node.
-    """
-    return (node.position[0] + node.size[0] / 2, node.position[1] + node.size[1] / 2)
+        :return: Formatted string.
+        :rtype: str
+        """
 
+        if bold:
+            return (
+                colored(string, "yellow", attrs=["bold"]) if QE_DEVELOPMENT else string
+            )
+        return colored(string, "yellow") if QE_DEVELOPMENT else string
 
-def get_formated_duplicates(list_size, list_of_duplicates, attr):
-    """
-    Take list of duplicates and format them for error message.
+    def get_formated_duplicates(self, list_size, list_of_duplicates, attr) -> str:
+        """
+        Take list of duplicates and format them for error message.
 
-    :type list_size: int
-    :param list_size: Size of the list_of_duplicates.
+        :type list_size: int
+        :param list_size: Size of the list_of_duplicates.
 
-    :type list_of_duplicates: list
-    :param list_of_duplicates: List of Nodes to handle for error message.
+        :type list_of_duplicates: list
+        :param list_of_duplicates: List of Nodes to handle for error message.
 
-    :type attr: string
-    :param attr: Node passed to the function.
+        :type attr: string
+        :param attr: Node passed to the function.
 
-    :rtype: string
-    :return: Formatted string output.
+        :rtype: string
+        :return: Formatted string output.
 
-    .. note::
+        .. note::
 
-        This serves only for the purpose of formatted error message upon search fail.
-        Used by :py:func:`get_error_message`.
-    """
+            This serves only for the purpose of formatted error message upon search fail.
+            Used by :py:func:`get_error_message`.
+        """
 
-    return (
-        "".join(
-            sorted(
-                set(
-                    [
-                        "\t{0}: '{1}' {2}: '{3}' {4}: '{5}' {6}: '{7}' {8}: '{9}'\n".format(
-                            colored("name", "yellow") if QE_DEVELOPMENT else "name",
-                            repr(node.name),
-                            colored("roleName", "yellow")
-                            if QE_DEVELOPMENT
-                            else "roleName",
-                            node.roleName,
-                            colored("position", "yellow")
-                            if QE_DEVELOPMENT
-                            else "position",
-                            node.position,
-                            colored("size", "yellow") if QE_DEVELOPMENT else "size",
-                            node.size,
-                            colored(f"{attr}", "yellow")
-                            if QE_DEVELOPMENT
-                            else f"{attr}"
-                            if attr
-                            else "attribute",
-                            getattr(node, attr) if attr else "None",
+        return (
+            "".join(
+                sorted(
+                    {
+                        "".join(
+                            (
+                                "\t",
+                                f"{self.format_string('name')}: '{repr(node.name)}' ",
+                                f"{self.format_string('roleName')}: '{node.roleName}' ",
+                                f"{self.format_string('position')}: '{node.position}' ",
+                                f"{self.format_string('size')}: '{node.size}' ",
+                                f"{self.format_string(attr if attr else 'attribute')}: ",
+                                f"'{getattr(node, attr) if attr else 'None'}'",
+                                "\n",
+                            )
                         )
                         for node in list_of_duplicates
-                    ]
-                ),
-                key=str.lower,
+                    },
+                    key=str.lower,
+                )
             )
+            if list_size != 0
+            else "\tNone\n"
         )
-        if list_size != 0
-        else "\tNone\n"
-    )
 
+    def get_formated_error_message(
+        self, error, node_name, same_name_items, node_role_name, same_role_name_items
+    ) -> str:
+        """
+        Take lists of duplicates with name and roleName and format them for error message.
 
-def get_formated_error_message(
-    error, node_name, same_name_items, node_role_name, same_role_name_items
-):
-    """
-    Take lists of duplicates with name and roleName and format them for error message.
+        :type error: string
+        :param error: Error - reason why the search for Node failed.
 
-    :type error: string
-    :param error: Error - reason why the search for Node failed.
+        :type node_name: string
+        :param node_name: Node.name that was searched for.
 
-    :type node_name: string
-    :param node_name: Node.name that was searched for.
+        :type same_name_items: list
+        :param same_name_items: List of all items with the name node_name.
 
-    :type same_name_items: list
-    :param same_name_items: List of all items with the name node_name.
+        :type node_role_name: string
+        :param node_role_name: Node.roleName that was searched for.
 
-    :type node_role_name: string
-    :param node_role_name: Node.roleName that was searched for.
+        :type same_role_name_items: list
+        :param same_role_name_items: List of all items with the roleName node_role_name.
 
-    :type same_role_name_items: list
-    :param same_role_name_items: List of all items with the roleName node_role_name.
+        :rtype: string
+        :return: Formatted string output of all :py:func:`get_formated_duplicates`
 
-    :rtype: string
-    :return: Formatted string output of all :py:func:`get_formated_duplicates`
+        .. note::
 
-    .. note::
+            This serves only for the purpose of formatted error message upon search fail.
+            Used by :py:func:`get_error_message`.
+        """
 
-        This serves only for the purpose of formatted error message upon search fail.
-        Used by :py:func:`get_error_message`.
-    """
-
-    return "".join(
-        [
-            "\n\n{0}: {1}\n\n{2}: {3}:\n{4}\n{5}: {6}:\n{7}\n".format(
-                colored("Item was not found", "yellow", attrs=["bold"])
-                if QE_DEVELOPMENT
-                else "Item was not found",
-                error,
-                colored("Items with name", "yellow", attrs=["bold"])
-                if QE_DEVELOPMENT
-                else "Items with name",
-                node_name,
+        return "".join(
+            (
+                "\n\n",
+                f"{self.format_string('Item was not found', bold=True)}: {error}",
+                "\n\n",
+                f"{self.format_string('Items with name', bold=True)}: {node_name}:",
+                "\n",
                 same_name_items,
-                colored("Items with roleName", "yellow", attrs=["bold"])
-                if QE_DEVELOPMENT
-                else "Items with roleName",
-                node_role_name,
+                "\n",
+                f"{self.format_string('Items with roleName', bold=True)}: {node_role_name}:",
+                "\n",
                 same_role_name_items,
+                "\n",
             )
-        ]
-    )
-
-
-def get_error_message(node, error):
-    """
-    Main handler for error message with :py:func:`get_formated_error_message` and
-    :py:func:`get_formated_duplicates` being used to get desired result.
-
-    :type node: GetNode
-    :param node: Instanced GetNode to have all data needed about the error.
-
-    :type error: string
-    :param error: Error message as to why the search failed.
-
-    .. note::
-
-        This serves only for the purpose of formatted error message upon search fail
-        when using :py:mod:`common_steps`.
-    """
-    name = repr(node.name)
-    nodes_with_name = []
-    if isinstance(node.name, str):
-        nodes_with_name = node.root.findChildren(
-            lambda x: node.name in x.name and (not (node.name != "") or x.name != "")
         )
-    elif isinstance(node.name, re.Pattern):
-        name = f"REGEX:{repr(node.name.pattern)}"
-        nodes_with_name = node.root.findChildren(
-            lambda x: re.fullmatch(node.name, x.name)
-        )
-    nodes_with_name_size = len(nodes_with_name)
-    nodes_with_name_formatted = get_formated_duplicates(
-        nodes_with_name_size, nodes_with_name, node.attr
-    )
-    role_name = repr(node.role_name)
-    nodes_with_role_name = []
-    if isinstance(node.role_name, str):
-        nodes_with_role_name = node.root.findChildren(
-            lambda x: node.role_name == x.roleName
-        )
-    elif isinstance(node.name, re.Pattern):
-        role_name = f"REGEX:{repr(node.role_name.pattern)}"
-        nodes_with_role_name = node.root.findChildren(
-            lambda x: re.fullmatch(node.role_name, x.roleName)
-        )
-    nodes_with_role_name_size = len(nodes_with_role_name)
-    nodes_with_role_name_formatted = get_formated_duplicates(
-        nodes_with_role_name_size, nodes_with_role_name, node.attr
-    )
 
-    return get_formated_error_message(
-        error,
-        name,
-        nodes_with_name_formatted,
-        role_name,
-        nodes_with_role_name_formatted,
-    )
+    def get_error_message(self, node, error) -> str:
+        """
+        Main handler for error message with :py:func:`get_formated_error_message` and
+        :py:func:`get_formated_duplicates` being used to get desired result.
+
+        :type node: GetNode
+        :param node: Instanced GetNode to have all data needed about the error.
+
+        :type error: string
+        :param error: Error message as to why the search failed.
+
+        .. note::
+
+            This serves only for the purpose of formatted error message upon search fail
+            when using :py:mod:`common_steps`.
+        """
+
+        name = repr(node.name)
+        nodes_with_name = []
+        if isinstance(node.name, str):
+            nodes_with_name = node.root.findChildren(
+                lambda x: node.name in x.name
+                and (not (node.name != "") or x.name != "")
+            )
+        elif isinstance(node.name, re.Pattern):
+            name = f"REGEX:{repr(node.name.pattern)}"
+            nodes_with_name = node.root.findChildren(
+                lambda x: re.fullmatch(node.name, x.name)
+            )
+        nodes_with_name_size = len(nodes_with_name)
+        nodes_with_name_formatted = self.get_formated_duplicates(
+            nodes_with_name_size, nodes_with_name, node.attr
+        )
+        role_name = repr(node.role_name)
+        nodes_with_role_name = []
+        if isinstance(node.role_name, str):
+            nodes_with_role_name = node.root.findChildren(
+                lambda x: node.role_name == x.roleName
+            )
+        elif isinstance(node.name, re.Pattern):
+            role_name = f"REGEX:{repr(node.role_name.pattern)}"
+            nodes_with_role_name = node.root.findChildren(
+                lambda x: re.fullmatch(node.role_name, x.roleName)
+            )
+        nodes_with_role_name_size = len(nodes_with_role_name)
+        nodes_with_role_name_formatted = self.get_formated_duplicates(
+            nodes_with_role_name_size, nodes_with_role_name, node.attr
+        )
+
+        return self.get_formated_error_message(
+            error,
+            name,
+            nodes_with_name_formatted,
+            role_name,
+            nodes_with_role_name_formatted,
+        )
